@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: hjsmin
-version: 0.1.5.3
-id: hjsmin-0.1.5.3-408bbfe5511e989538833527e5c06f0a
-key: hjsmi_1zqeTuGvajw0vUqpC3dJ2B
+version: 0.2.0.1
+id: hjsmin-0.2.0.1-46670f54640c2d75932d2d7d196eac09
+key: hjsmi_2DQCkN6Ap7iCiYZ3pBgxpD
 license: BSD3
 maintainer: Erik de Castro Lopo <erikd@mega-nerd.com>
 stability: unstable
@@ -19,17 +19,17 @@ exposed-modules:
     Text.Jasmine
 hidden-modules: Text.Jasmine.Pretty
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/hjsmin-0.1.5.3
-library-dirs: /usr/lib/ghc-7.10.3/site-local/hjsmin-0.1.5.3
-data-dir: /usr/share/arm-linux-ghc-7.10.3/hjsmin-0.1.5.3
-hs-libraries: HShjsmin-0.1.5.3-1zqeTuGvajw0vUqpC3dJ2B
+import-dirs: /usr/lib/ghc-7.10.3/site-local/hjsmin-0.2.0.1
+library-dirs: /usr/lib/ghc-7.10.3/site-local/hjsmin-0.2.0.1
+data-dir: /usr/share/arm-linux-ghc-7.10.3/hjsmin-0.2.0.1
+hs-libraries: HShjsmin-0.2.0.1-2DQCkN6Ap7iCiYZ3pBgxpD
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-3daa45cd3be9618b289586d273c59e36
+    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    language-javascript-0.5.14.2-f55c8cd80a337ed6a6cb1df128d3b4c5
-    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    language-javascript-0.6.0.2-b872ffab7eb92e354d2028cc73df3cc6
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
 haddock-interfaces: /usr/share/doc/haskell-hjsmin/html/hjsmin.haddock
 haddock-html: /usr/share/doc/haskell-hjsmin/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
